.. StagPy documentation master file, created by
   sphinx-quickstart on Fri Feb 19 19:57:27 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to StagPy's documentation!
==================================


.. toctree::
   :maxdepth: 2
   :caption: Diving in

   sources/install
   sources/tuto
   sources/stagyydata
   sources/cli
   sources/cookbook

.. toctree::
   :maxdepth: 2
   :caption: For developers

   sources/developers
   sources/maintainers

.. toctree::
   :maxdepth: 2
   :caption: API Reference

   sources/apiref/stagpy
   sources/apiref/commands
   sources/apiref/config
   sources/apiref/error
   sources/apiref/field
   sources/apiref/misc
   sources/apiref/parfile
   sources/apiref/phyvars
   sources/apiref/processing
   sources/apiref/rprof
   sources/apiref/stagyydata
   sources/apiref/stagyyparsers
   sources/apiref/time

